abstract class OperationState {}

class OperationIdle extends OperationState {}

class OperationInProgress extends OperationState {
  String? message;

  OperationInProgress({this.message});
}

class OperationFailed extends OperationState {
  String message;

  OperationFailed({required this.message});
}

class OperationFinished extends OperationState {
  String? message;

  OperationFinished({this.message});
}
